@@ -30,8 +30,3 @@ class BaseAggregate(abc.ABC):
 
     def __hash__(self):
         return hash(self.reference)
-
-    def check_by_parameters(self, **kwargs):
-        if 'reference' in kwargs:
-            return self.reference == kwargs['reference']
-        return False
