@@ -7,6 +7,16 @@ from dddmisc import AbstractAsyncUnitOfWork, AbstractAsyncRepository, DDDEvent,
 from dddmisc.messagebus.abstract import AbstractMessagebus, HandlerConfig
 
 
+class EventHandlerProtocol(t.Protocol):
+
+    async def __call__(self, event: DDDEvent, uow: AbstractAsyncUnitOfWork) -> t.NoReturn: ...
+
+
+class CommandHandlerProtocol(t.Protocol):
+
+    async def __call__(self, command: DDDCommand, uow: AbstractAsyncUnitOfWork) -> t.Any: ...
+
+
 class AsyncMessageBus(AbstractMessagebus):
     _loop: asyncio.AbstractEventLoop
 
@@ -53,7 +63,7 @@ class AsyncMessageBus(AbstractMessagebus):
     @t.overload
     def register(self,
                  message: t.Type[DDDEvent],
-                 handler: t.Callable[[DDDEvent, AbstractAsyncUnitOfWork], t.Awaitable[None]],
+                 handler: EventHandlerProtocol,
                  *,
                  unit_of_work: t.Optional[t.Type[AbstractAsyncUnitOfWork]] = None,
                  repository: t.Optional[t.Type[AbstractAsyncRepository]] = None,
@@ -63,7 +73,7 @@ class AsyncMessageBus(AbstractMessagebus):
     @t.overload
     def register(self,
                  message: t.Type[DDDCommand],
-                 handler: t.Callable[[DDDCommand, AbstractAsyncUnitOfWork], t.Awaitable[t.Any]],
+                 handler: CommandHandlerProtocol,
                  *,
                  unit_of_work: t.Optional[t.Type[AbstractAsyncUnitOfWork]] = None,
                  repository: t.Optional[t.Type[AbstractAsyncRepository]] = None,
