@@ -9,6 +9,16 @@ from dddmisc import DDDEvent, AbstractSyncUnitOfWork, AbstractSyncRepository, DD
 from dddmisc.messagebus.abstract import AbstractMessagebus, HandlerConfig
 
 
+class EventHandlerProtocol(t.Protocol):
+
+    def __call__(self, event: DDDEvent, uow: AbstractSyncUnitOfWork) -> t.NoReturn: ...
+
+
+class CommandHandlerProtocol(t.Protocol):
+
+    def __call__(self, command: DDDCommand, uow: AbstractSyncUnitOfWork) -> t.Any: ...
+
+
 class EventThreadExecutor(threading.Thread):
     def __init__(self, event: DDDEvent, handler, executor, finish_callback: t.Callable):
         self.event = event
@@ -72,7 +82,7 @@ class MessageBus(AbstractMessagebus):
     @t.overload
     def register(self,
                  message: t.Type[DDDEvent],
-                 handler: t.Callable[[DDDEvent, AbstractSyncUnitOfWork], None],
+                 handler: EventHandlerProtocol,
                  *,
                  unit_of_work: t.Optional[t.Type[AbstractSyncUnitOfWork]] = None,
                  repository: t.Optional[t.Type[AbstractSyncRepository]] = None,
@@ -82,7 +92,7 @@ class MessageBus(AbstractMessagebus):
     @t.overload
     def register(self,
                  message: t.Type[DDDCommand],
-                 handler: t.Callable[[DDDCommand, AbstractSyncUnitOfWork], t.Any],
+                 handler: CommandHandlerProtocol,
                  *,
                  unit_of_work: t.Optional[t.Type[AbstractSyncUnitOfWork]] = None,
                  repository: t.Optional[t.Type[AbstractSyncRepository]] = None,
